@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Capture::Tiny;
 # ABSTRACT: Capture STDOUT and STDERR from Perl, XS or external programs
-our $VERSION = '0.31'; # TRIAL
+our $VERSION = '0.37'; # TRIAL
 use Carp ();
 use Exporter ();
 use IO::Handle ();
@@ -436,39 +436,39 @@ Capture::Tiny - Capture STDOUT and STDERR from Perl, XS or external programs
 
 =head1 VERSION
 
-version 0.31
+version 0.37
 
 =head1 SYNOPSIS
 
-   use Capture::Tiny ':all';
- 
-   # capture from external command
- 
-   ($stdout, $stderr, $exit) = capture {
-     system( $cmd, @args );
-   };
- 
-   # capture from arbitrary code (Perl or external)
- 
-   ($stdout, $stderr, @result) = capture {
-     # your code here
-   };
- 
-   # capture partial or merged output
- 
-   $stdout = capture_stdout { ... };
-   $stderr = capture_stderr { ... };
-   $merged = capture_merged { ... };
- 
-   # tee output
- 
-   ($stdout, $stderr) = tee {
-     # your code here
-   };
- 
-   $stdout = tee_stdout { ... };
-   $stderr = tee_stderr { ... };
-   $merged = tee_merged { ... };
+  use Capture::Tiny ':all';
+
+  # capture from external command
+
+  ($stdout, $stderr, $exit) = capture {
+    system( $cmd, @args );
+  };
+
+  # capture from arbitrary code (Perl or external)
+
+  ($stdout, $stderr, @result) = capture {
+    # your code here
+  };
+
+  # capture partial or merged output
+
+  $stdout = capture_stdout { ... };
+  $stderr = capture_stderr { ... };
+  $merged = capture_merged { ... };
+
+  # tee output
+
+  ($stdout, $stderr) = tee {
+    # your code here
+  };
+
+  $stdout = tee_stdout { ... };
+  $stderr = tee_stderr { ... };
+  $merged = tee_merged { ... };
 
 =head1 DESCRIPTION
 
@@ -485,10 +485,10 @@ The following functions are available.  None are exported by default.
 
 =head2 capture
 
-   ($stdout, $stderr, @result) = capture \&code;
-   $stdout = capture \&code;
+  ($stdout, $stderr, @result) = capture \&code;
+  $stdout = capture \&code;
 
-The C<<< capture >>> function takes a code reference and returns what is sent to
+The C<capture> function takes a code reference and returns what is sent to
 STDOUT and STDERR as well as any return values from the code reference.  In
 scalar context, it returns only STDOUT.  If no output was received for a
 filehandle, it returns an empty string for that filehandle.  Regardless of calling
@@ -497,70 +497,70 @@ context, all output is captured -- nothing is passed to the existing filehandles
 It is prototyped to take a subroutine reference as an argument. Thus, it
 can be called in block form:
 
-   ($stdout, $stderr) = capture {
-     # your code here ...
-   };
+  ($stdout, $stderr) = capture {
+    # your code here ...
+  };
 
 Note that the coderef is evaluated in list context.  If you wish to force
-scalar context on the return value, you must use the C<<< scalar >>> keyword.
+scalar context on the return value, you must use the C<scalar> keyword.
 
-   ($stdout, $stderr, $count) = capture {
-     my @list = qw/one two three/;
-     return scalar @list; # $count will be 3
-   };
+  ($stdout, $stderr, $count) = capture {
+    my @list = qw/one two three/;
+    return scalar @list; # $count will be 3
+  };
 
-Also note that within the coderef, the C<<< @_ >>> variable will be empty.  So don't
+Also note that within the coderef, the C<@_> variable will be empty.  So don't
 use arguments from a surrounding subroutine without copying them to an array
 first:
 
-   sub wont_work {
-     my ($stdout, $stderr) = capture { do_stuff( @_ ) };    # WRONG
-     ...
-   }
- 
-   sub will_work {
-     my @args = @_;
-     my ($stdout, $stderr) = capture { do_stuff( @args ) }; # RIGHT
-     ...
-   }
+  sub wont_work {
+    my ($stdout, $stderr) = capture { do_stuff( @_ ) };    # WRONG
+    ...
+  }
+
+  sub will_work {
+    my @args = @_;
+    my ($stdout, $stderr) = capture { do_stuff( @args ) }; # RIGHT
+    ...
+  }
 
 Captures are normally done to an anonymous temporary filehandle.  To
 capture via a named file (e.g. to externally monitor a long-running capture),
 provide custom filehandles as a trailing list of option pairs:
 
-   my $out_fh = IO::File->new("out.txt", "w+");
-   my $err_fh = IO::File->new("out.txt", "w+");
-   capture { ... } stdout => $out_fh, stderr => $err_fh;
+  my $out_fh = IO::File->new("out.txt", "w+");
+  my $err_fh = IO::File->new("out.txt", "w+");
+  capture { ... } stdout => $out_fh, stderr => $err_fh;
 
-The filehandles must be readE<sol>write and seekable.  Modifying the files or
+The filehandles must be read/write and seekable.  Modifying the files or
 filehandles during a capture operation will give unpredictable results.
 Existing IO layers on them may be changed by the capture.
 
-When called in void context, C<<< capture >>> saves memory and time by
+When called in void context, C<capture> saves memory and time by
 not reading back from the capture handles.
 
 =head2 capture_stdout
 
-   ($stdout, @result) = capture_stdout \&code;
-   $stdout = capture_stdout \&code;
+  ($stdout, @result) = capture_stdout \&code;
+  $stdout = capture_stdout \&code;
 
-The C<<< capture_stdout >>> function works just like C<<< capture >>> except only
+The C<capture_stdout> function works just like C<capture> except only
 STDOUT is captured.  STDERR is not captured.
 
 =head2 capture_stderr
 
-   ($stderr, @result) = capture_stderr \&code;
-   $stderr = capture_stderr \&code;
+  ($stderr, @result) = capture_stderr \&code;
+  $stderr = capture_stderr \&code;
 
-The C<<< capture_stderr >>> function works just like C<<< capture >>> except only
+The C<capture_stderr> function works just like C<capture> except only
 STDERR is captured.  STDOUT is not captured.
 
 =head2 capture_merged
 
-   ($merged, @result) = capture_merged \&code;
-   $merged = capture_merged \&code;
+  ($merged, @result) = capture_merged \&code;
+  $merged = capture_merged \&code;
 
-The C<<< capture_merged >>> function works just like C<<< capture >>> except STDOUT and
+The C<capture_merged> function works just like C<capture> except STDOUT and
 STDERR are merged. (Technically, STDERR is redirected to the same capturing
 handle as STDOUT before executing the function.)
 
@@ -569,39 +569,39 @@ properly ordered due to buffering.
 
 =head2 tee
 
-   ($stdout, $stderr, @result) = tee \&code;
-   $stdout = tee \&code;
+  ($stdout, $stderr, @result) = tee \&code;
+  $stdout = tee \&code;
 
-The C<<< tee >>> function works just like C<<< capture >>>, except that output is captured
+The C<tee> function works just like C<capture>, except that output is captured
 as well as passed on to the original STDOUT and STDERR.
 
-When called in void context, C<<< tee >>> saves memory and time by
+When called in void context, C<tee> saves memory and time by
 not reading back from the capture handles, except when the
 original STDOUT OR STDERR were tied or opened to a scalar
 handle.
 
 =head2 tee_stdout
 
-   ($stdout, @result) = tee_stdout \&code;
-   $stdout = tee_stdout \&code;
+  ($stdout, @result) = tee_stdout \&code;
+  $stdout = tee_stdout \&code;
 
-The C<<< tee_stdout >>> function works just like C<<< tee >>> except only
+The C<tee_stdout> function works just like C<tee> except only
 STDOUT is teed.  STDERR is not teed (output goes to STDERR as usual).
 
 =head2 tee_stderr
 
-   ($stderr, @result) = tee_stderr \&code;
-   $stderr = tee_stderr \&code;
+  ($stderr, @result) = tee_stderr \&code;
+  $stderr = tee_stderr \&code;
 
-The C<<< tee_stderr >>> function works just like C<<< tee >>> except only
+The C<tee_stderr> function works just like C<tee> except only
 STDERR is teed.  STDOUT is not teed (output goes to STDOUT as usual).
 
 =head2 tee_merged
 
-   ($merged, @result) = tee_merged \&code;
-   $merged = tee_merged \&code;
+  ($merged, @result) = tee_merged \&code;
+  $merged = tee_merged \&code;
 
-The C<<< tee_merged >>> function works just like C<<< capture_merged >>> except that output
+The C<tee_merged> function works just like C<capture_merged> except that output
 is captured as well as passed on to STDOUT.
 
 Caution: STDOUT and STDERR output in the merged result are not guaranteed to be
@@ -611,17 +611,17 @@ properly ordered due to buffering.
 
 =head2 Portability
 
-Portability is a goal, not a guarantee.  C<<< tee >>> requires fork, except on
-Windows where C<<< system(1, @cmd) >>> is used instead.  Not tested on any
+Portability is a goal, not a guarantee.  C<tee> requires fork, except on
+Windows where C<system(1, @cmd)> is used instead.  Not tested on any
 particularly esoteric platforms yet.  See the
 L<CPAN Testers Matrix|http://matrix.cpantesters.org/?dist=Capture-Tiny>
 for test result by platform.
 
 =head2 PerlIO layers
 
-Capture::Tiny does it's best to preserve PerlIO layers such as ':utf8' or
+Capture::Tiny does its best to preserve PerlIO layers such as ':utf8' or
 ':crlf' when capturing (only for Perl 5.8.1+) .  Layers should be applied to
-STDOUT or STDERR I<before> the call to C<<< capture >>> or C<<< tee >>>.  This may not work
+STDOUT or STDERR I<before> the call to C<capture> or C<tee>.  This may not work
 for tied filehandles (see below).
 
 =head2 Modifying filehandles before capturing
@@ -629,11 +629,11 @@ for tied filehandles (see below).
 Generally speaking, you should do little or no manipulation of the standard IO
 filehandles prior to using Capture::Tiny.  In particular, closing, reopening,
 localizing or tying standard filehandles prior to capture may cause a variety of
-unexpected, undesirable andE<sol>or unreliable behaviors, as described below.
+unexpected, undesirable and/or unreliable behaviors, as described below.
 Capture::Tiny does its best to compensate for these situations, but the
 results may not be what you desire.
 
-B<Closed filehandles>
+=head3 Closed filehandles
 
 Capture::Tiny will work even if STDIN, STDOUT or STDERR have been previously
 closed.  However, since they will be reopened to capture or tee output, any
@@ -648,18 +648,18 @@ descriptor 0, as this causes problems on various platforms.
 Prior to Perl 5.12, closed STDIN combined with PERL_UNICODE=D leaks filehandles
 and also breaks tee() for undiagnosed reasons.  So don't do that.
 
-B<Localized filehandles>
+=head3 Localized filehandles
 
 If code localizes any of Perl's standard filehandles before capturing, the capture
 will affect the localized filehandles and not the original ones.  External system
 calls are not affected by localizing a filehandle in Perl and will continue
 to send output to the original filehandles (which will thus not be captured).
 
-B<Scalar filehandles>
+=head3 Scalar filehandles
 
 If STDOUT or STDERR are reopened to scalar filehandles prior to the call to
-C<<< capture >>> or C<<< tee >>>, then Capture::Tiny will override the output filehandle for
-the duration of the C<<< capture >>> or C<<< tee >>> call and then, for C<<< tee >>>, send captured
+C<capture> or C<tee>, then Capture::Tiny will override the output filehandle for
+the duration of the C<capture> or C<tee> call and then, for C<tee>, send captured
 output to the output filehandle after the capture is complete.  (Requires Perl
 5.8)
 
@@ -668,20 +668,20 @@ reference, but note that external processes will not be able to read from such
 a handle.  Capture::Tiny tries to ensure that external processes will read from
 the null device instead, but this is not guaranteed.
 
-B<Tied output filehandles>
+=head3 Tied output filehandles
 
-If STDOUT or STDERR are tied prior to the call to C<<< capture >>> or C<<< tee >>>, then
+If STDOUT or STDERR are tied prior to the call to C<capture> or C<tee>, then
 Capture::Tiny will attempt to override the tie for the duration of the
-C<<< capture >>> or C<<< tee >>> call and then send captured output to the tied filehandle after
+C<capture> or C<tee> call and then send captured output to the tied filehandle after
 the capture is complete.  (Requires Perl 5.8)
 
 Capture::Tiny may not succeed resending UTF-8 encoded data to a tied
 STDOUT or STDERR filehandle.  Characters may appear as bytes.  If the tied filehandle
 is based on L<Tie::StdHandle>, then Capture::Tiny will attempt to determine
-appropriate layers like C<<< :utf8 >>> from the underlying filehandle and do the right
+appropriate layers like C<:utf8> from the underlying filehandle and do the right
 thing.
 
-B<Tied input filehandle>
+=head3 Tied input filehandle
 
 Capture::Tiny attempts to preserve the semantics of tied STDIN, but this
 requires Perl 5.8 and is not entirely predictable.  External processes
@@ -690,14 +690,14 @@ will not be able to read from such a handle.
 Unless having STDIN tied is crucial, it may be safest to localize STDIN when
 capturing:
 
-   my ($out, $err) = do { local *STDIN; capture { ... } };
+  my ($out, $err) = do { local *STDIN; capture { ... } };
 
 =head2 Modifying filehandles during a capture
 
-Attempting to modify STDIN, STDOUT or STDERR I<during> C<<< capture >>> or C<<< tee >>> is
+Attempting to modify STDIN, STDOUT or STDERR I<during> C<capture> or C<tee> is
 almost certainly going to cause problems.  Don't do that.
 
-B<Forking inside a capture>
+=head3 Forking inside a capture
 
 Forks aren't portable.  The behavior of filehandles during a fork is even
 less so.  If Capture::Tiny detects that a fork has occurred within a
@@ -718,18 +718,18 @@ Perl 5.6 predates PerlIO.  UTF-8 data may not be captured correctly.
 
 =head2 PERL_CAPTURE_TINY_TIMEOUT
 
-Capture::Tiny uses subprocesses internally for C<<< tee >>>.  By default,
+Capture::Tiny uses subprocesses internally for C<tee>.  By default,
 Capture::Tiny will timeout with an error if such subprocesses are not ready to
 receive data within 30 seconds (or whatever is the value of
-C<<< $Capture::Tiny::TIMEOUT >>>).  An alternate timeout may be specified by setting
-the C<<< PERL_CAPTURE_TINY_TIMEOUT >>> environment variable.  Setting it to zero will
-disable timeouts.  BE<lt>NOTEE<gt>, this does not timeout the code reference being
+C<$Capture::Tiny::TIMEOUT>).  An alternate timeout may be specified by setting
+the C<PERL_CAPTURE_TINY_TIMEOUT> environment variable.  Setting it to zero will
+disable timeouts.  B<NOTE>, this does not timeout the code reference being
 captured -- this only prevents Capture::Tiny itself from hanging your process
 waiting for its child processes to be ready to proceed.
 
 =head1 SEE ALSO
 
-This module was, inspired by L<IO::CaptureOutput>, which provides
+This module was inspired by L<IO::CaptureOutput>, which provides
 similar functionality without the ability to tee output and with more
 complicated code and API.  L<IO::CaptureOutput> does not handle layers
 or most of the unusual cases described in the L</Limitations> section and
@@ -740,7 +740,7 @@ albeit with various limitations that make them appropriate only in particular
 circumstances.  I'm probably missing some.  The long list is provided to show
 why I felt Capture::Tiny was necessary.
 
-=over
+=over 4
 
 =item *
 
@@ -853,7 +853,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dagfinn Ilmari Mannsåker David E. Wheeler Golden fecundf
+=for stopwords Dagfinn Ilmari Mannsåker David E. Wheeler fecundf
 
 =over 4
 
@@ -867,10 +867,6 @@ David E. Wheeler <david@justatheory.com>
 
 =item *
 
-David Golden <xdg@xdg.me>
-
-=item *
-
 fecundf <not.com+github@gmail.com>
 
 =back
